from giza_datasets.defillama_constants import DEFILLAMA_SUPPORTED_PROJECTS
from giza_datasets.models import Dataset

APPLICATION_TAGS = ["Liquid Staking", "Dexes", "Yield", "Lending", "Yield Aggregator"]

DATASET_HUB = [
    Dataset(
        name="tvl-fee-per-protocol",
        path="gs://datasets-giza/TVL_fee_per_protocol",
        description="TVL and fees for each protocol-chain pair and for each day.",
        tags=["aggregated", "daily", "TVL", "Fees", "Multi-chain"]
        + DEFILLAMA_SUPPORTED_PROJECTS
        + APPLICATION_TAGS,
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/tvl-and-fees-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens",
        path="gs://datasets-giza/TVL_per_project_tokens",
        description="Dataset partitioned by project. Each partition contains the daily historical TVL of the tokens used by the project.",
        tags=["aggregated", "daily", "TVL"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/tvl-for-each-token-by-protocol",
    ),
    Dataset(
        name="tokens-ohcl",
        path="gs://datasets-giza/tokens_OHCL/tokens_OHCL.parquet",
        description="The Open, High, Low, and Close value of a selection of tokens every 4 days since the token's creation.",
        tags=["aggregated", "daily", "Token Price"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/tokens-ohlc-price",
    ),
    Dataset(
        name="top-pools-apy-per-protocol",
        path="gs://datasets-giza/top_pools_APY_per_protocol",
        description="Daily historical APY of the pools with the highest TVL for each project described in the tvl-fee-per-protocol dataset",
        tags=["aggregated", "daily", "APY"]
        + DEFILLAMA_SUPPORTED_PROJECTS
        + APPLICATION_TAGS,
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=aave-v2",
        path="gs://datasets-giza/TVL_per_project_tokens/project=aave-v2",
        description="Daily historical TVL of the tokens supported by aave-v2.",
        tags=["aggregated", "daily", "TVL", "aave-v2"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=aave-v3",
        path="gs://datasets-giza/TVL_per_project_tokens/project=aave-v3",
        description="Daily historical TVL of the tokens supported by aave-v3",
        tags=["aggregated", "daily", "TVL", "aave-v3"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=aura",
        path="gs://datasets-giza/TVL_per_project_tokens/project=aura",
        description="Daily historical TVL of the tokens supported by aura",
        tags=["aggregated", "daily", "TVL", "aura"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=balancer-v2",
        path="gs://datasets-giza/TVL_per_project_tokens/project=balancer-v2",
        description="Daily historical TVL of the tokens supported by balancer-v2",
        tags=["aggregated", "daily", "TVL", "balancer-v2"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=beefy",
        path="gs://datasets-giza/TVL_per_project_tokens/project=beefy",
        description="Daily historical TVL of the tokens supported by beefy",
        tags=["aggregated", "daily", "TVL", "beefy"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=benqi-lending",
        path="gs://datasets-giza/TVL_per_project_tokens/project=benqi-lending",
        description="Daily historical TVL of the tokens supported by benqi-lending",
        tags=["aggregated", "daily", "TVL", "benqi-lending"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=coinwind",
        path="gs://datasets-giza/TVL_per_project_tokens/project=coinwind",
        description="Daily historical TVL of the tokens supported by coinwind",
        tags=["aggregated", "daily", "TVL", "coinwind"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=compound-v2",
        path="gs://datasets-giza/TVL_per_project_tokens/project=compound-v2",
        description="Daily historical TVL of the tokens supported by compound-v2",
        tags=["aggregated", "daily", "TVL", "compound-v2"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=convex-finance",
        path="gs://datasets-giza/TVL_per_project_tokens/project=convex-finance",
        description="Daily historical TVL of the tokens supported by convex-finance",
        tags=["aggregated", "daily", "TVL", "convex-finance"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=curve-dex",
        path="gs://datasets-giza/TVL_per_project_tokens/project=curve-dex",
        description="Daily historical TVL of the tokens supported by curve-dex",
        tags=["aggregated", "daily", "TVL", "curve-dex"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=flamincome",
        path="gs://datasets-giza/TVL_per_project_tokens/project=flamincome",
        description="Daily historical TVL of the tokens supported by flamincome",
        tags=["aggregated", "daily", "TVL", "flamincome"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=lido",
        path="gs://datasets-giza/TVL_per_project_tokens/project=lido",
        description="Daily historical TVL of the tokens supported by lido",
        tags=["aggregated", "daily", "TVL", "lido"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=pancakeswap-amm",
        path="gs://datasets-giza/TVL_per_project_tokens/project=pancakeswap-amm",
        description="Daily historical TVL of the tokens supported by pancakeswap-amm",
        tags=["aggregated", "daily", "TVL", "pancakeswap-amm"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=pendle",
        path="gs://datasets-giza/TVL_per_project_tokens/project=pendle",
        description="Daily historical TVL of the tokens supported by pendle",
        tags=["aggregated", "daily", "TVL", "pendle"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=rocket-pool",
        path="gs://datasets-giza/TVL_per_project_tokens/project=rocket-pool",
        description="Daily historical TVL of the tokens supported by rocket-pool",
        tags=["aggregated", "daily", "TVL", "rocket-pool"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=sushiswap",
        path="gs://datasets-giza/TVL_per_project_tokens/project=sushiswap",
        description="Daily historical TVL of the tokens supported by sushiswap",
        tags=["aggregated", "daily", "TVL", "sushiswap"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=uniswap-v2",
        path="gs://datasets-giza/TVL_per_project_tokens/project=uniswap-v2",
        description="Daily historical TVL of the tokens supported by uniswap-v2",
        tags=["aggregated", "daily", "TVL", "uniswap-v2"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=uniswap-v3",
        path="gs://datasets-giza/TVL_per_project_tokens/project=uniswap-v3",
        description="Daily historical TVL of the tokens supported by uniswap-v3",
        tags=["aggregated", "daily", "TVL", "uniswap-v3"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="tvl-per-project-tokens/project=yearn-finance",
        path="gs://datasets-giza/TVL_per_project_tokens/project=yearn-finance",
        description="Daily historical TVL of the tokens supported by yearn-finance",
        tags=["aggregated", "daily", "TVL", "yearn-finance"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/top-pools-apy-per-protocol",
    ),
    Dataset(
        name="aave-daily-deposits-borrowsv2",
        path="gs://datasets-giza/Aave/Aave_Daily_Deposits_BorrowsV2.parquet",
        description="Daily deposits and borrows per pool in Aave V2",
        tags=["DeFi", "Lending", "Aave-v2", "Ethereum", "Borrows & Deposits"],
        documentation="https://datasets.gizatech.xyz/hub/aave/daily-deposits-and-borrows-v2",
    ),
    Dataset(
        name="aave-daily-deposits-borrowsv3",
        path="gs://datasets-giza/Aave/Aave_Daily_Deposits_BorrowsV3.parquet",
        description="Daily deposits and borrows per pool in Aave V3",
        tags=["DeFi", "Lending", "Aave-v3", "Ethereum", "Borrows & Deposits"],
        documentation="https://datasets.gizatech.xyz/hub/aave/daily-deposits-and-borrows-v3",
    ),
    Dataset(
        name="aave-daily-rates-indexes",
        path="gs://datasets-giza/Aave/Aave_Daily_Rates_Indexes.parquet",
        description="Daily average stable and variable borrow rates, as well as liquidity and borrow indexes per pool in Aave V3 and V2",
        tags=["DeFi", "Lending", "Aave-v3", "Ethereum", "Swap Fees"],
        documentation="https://datasets.gizatech.xyz/hub/aave/daily-exchange-rates-and-indexes-v3",
    ),
    Dataset(
        name="balancer-daily-pool-liquidity",
        path="gs://datasets-giza/Balancer/Balancer_Daily_Pool_Liquidity.parquet",
        description="Daily available liquidity in token and usd values per pool in Balancer",
        tags=[
            "DeFi",
            "DEX",
            "Balancer-v1",
            "Balancer-v2",
            "Ethereum",
            "Arbitrum",
            "Optimism",
            "Avalanche",
            "Base",
            "Gnosis",
            "Polygon",
            "Liquidity",
        ],
        documentation="https://datasets.gizatech.xyz/hub/balancer/daily-pool-liquidity",
    ),
    Dataset(
        name="balancer-daily-swap-fees",
        path="gs://datasets-giza/Balancer/Balancer_Daily_Swap_Fees.parquet",
        description="Daily average swap fees per pool in Balancer",
        tags=[
            "DeFi",
            "DEX",
            "Balancer-v1",
            "Balancer-v2",
            "Ethereum",
            "Arbitrum",
            "Optimism",
            "Avalanche",
            "Base",
            "Gnosis",
            "Polygon",
            "Swap Fees",
        ],
        documentation="https://datasets.gizatech.xyz/hub/balancer/daily-swap-fees",
    ),
    Dataset(
        name="balancer-daily-trade-volume",
        path="gs://datasets-giza/Balancer/Balancer_Daily_Trade_Volume.parquet",
        description="Daily aggregate trading volume per pool in Balancer",
        tags=[
            "DeFi",
            "DEX",
            "Balancer-v1",
            "Balancer-v2",
            "Ethereum",
            "Arbitrum",
            "Optimism",
            "Avalanche",
            "Base",
            "Gnosis",
            "Polygon",
            "Trade Volume",
        ],
        documentation="https://datasets.gizatech.xyz/hub/balancer/daily-trade-volume",
    ),
    Dataset(
        name="yearn-individual-deposits",
        path="gs://datasets-giza/Yearn/Yearn_Individual_Deposits.parquet",
        description="Individual Yearn Vault deposits",
        tags=["DeFi", "Yield", "Yearn-v2", "Ethereum", "Deposits"],
        documentation="https://datasets.gizatech.xyz/hub/yearn/individual-vault-deposits",
    ),
    Dataset(
        name="yearn-individual-withdraws",
        path="gs://datasets-giza/Yearn/Yearn_Individual_Withdraws.parquet",
        description="Individual Yearn Vault withdraws",
        tags=["DeFi", "Yield", "Yearn-v2", "Ethereum", "Withdraws"],
        documentation="https://datasets.gizatech.xyz/hub/yearn/individual-vault-withdraws",
    ),
    Dataset(
        name="yearn-strategy-borrows",
        path="gs://datasets-giza/Yearn/Yearn_Strategy_Borrows.parquet",
        description="Individual Yearn Vault withdraws from the associated Yearn Strategies",
        tags=["DeFi", "Yield", "Yearn-v2", "Ethereum", "Withdraws"],
        documentation="https://datasets.gizatech.xyz/hub/yearn/strategy-borrows",
    ),
    Dataset(
        name="yearn-strategy-returns",
        path="gs://datasets-giza/Yearn/Yearn_Strategy_Returns.parquet",
        description="Individual Yearn Vault deposits from the associated Yearn Strategies",
        tags=["DeFi", "Yield", "Yearn-v2", "Ethereum", "Deposits"],
        documentation="https://datasets.gizatech.xyz/hub/yearn/strategy-returns",
    ),
    Dataset(
        name="compound-daily-interest-rates",
        path="gs://datasets-giza/CompoundV2/compound_v2_rates.parquet",
        description="Daily interest rates for each Compound V2 market on Ethereum mainnet",
        tags=["DeFi", "Compound-v2", "Ethereum", "Interest Rates", "Lending"],
        documentation="https://app.gitbook.com/o/hEO6HqxrZikLvldqIQyx/s/pl74PhvrIKrt4DXJOVTt/hub-pending/compound-v2-interest-rates",
    ),
    Dataset(
        name="uniswapv3-ethereum-pools-info",
        path="gs://datasets-giza/UniswapV3/pools_info.parquet",
        description="Information about Uniswap V3 pools on ethereum",
        tags=["DeFi", "Uniswap-v3", "Ethereum", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arkm-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/ARKM_WETH_10000/merged_snaps_17718859_18083859.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for ARKM-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arkm-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/ARKM_WETH_10000/merged_ticks_17718859_18083859.parquet",
        description="Current ticks of Uniswap V3 ARKM-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pdt-prime-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PDT_PRIME_10000/merged_snaps_16991469_18064469.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PDT-PRIME pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pdt-prime-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PDT_PRIME_10000/merged_ticks_16991469_18064469.parquet",
        description="Current ticks of Uniswap V3 PDT-PRIME pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-halal-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_HALAL_3000/merged_ticks_18042155_18062155.parquet",
        description="Current ticks of Uniswap V3 WETH-HALAL pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-halal-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_HALAL_3000/merged_snaps_18042155_18062155.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-HALAL pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-send-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/send_WETH_10000/merged_ticks_17580369_18085369.parquet",
        description="Current ticks of Uniswap V3 send-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-send-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/send_WETH_10000/merged_snaps_17580369_18085369.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for send-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-babyrfd-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BABYRFD_WETH_10000/merged_snaps_17306428_17337428.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BABYRFD-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-babyrfd-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BABYRFD_WETH_10000/merged_ticks_17306428_17337428.parquet",
        description="Current ticks of Uniswap V3 BABYRFD-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-our-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_OUR_3000/merged_ticks_12989974_15995974.parquet",
        description="Current ticks of Uniswap V3 USDC-OUR pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-our-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_OUR_3000/merged_snaps_12989974_15995974.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-OUR pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-fldx-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/FLDX_USDC_500/merged_ticks_12505337_16965337.parquet",
        description="Current ticks of Uniswap V3 FLDX-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-fldx-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/FLDX_USDC_500/merged_snaps_12505337_16965337.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for FLDX-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-usdc-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_USDC_10000/merged_ticks_16628713_18067713.parquet",
        description="Current ticks of Uniswap V3 BLUR-USDC pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-usdc-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_USDC_10000/merged_snaps_16628713_18067713.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BLUR-USDC pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-cdt-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_CDT_10000/merged_ticks_16514607_18045607.parquet",
        description="Current ticks of Uniswap V3 WETH-CDT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-cdt-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_CDT_10000/merged_snaps_16514607_18045607.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-CDT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-liquidator-weth-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LIQUIDATOR_WETH_100/merged_ticks_14083352_14083352.parquet",
        description="Current ticks of Uniswap V3 LIQUIDATOR-WETH pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-liquidator-weth-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LIQUIDATOR_WETH_100/merged_snaps_14083352_14083352.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LIQUIDATOR-WETH pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-aave-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_AAVE_3000/merged_snaps_12503957_17996957.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-AAVE pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-aave-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_AAVE_3000/merged_ticks_12503957_17996957.parquet",
        description="Current ticks of Uniswap V3 UNI-AAVE pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wooo-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/wooo_WETH_10000/merged_ticks_17613890_18074890.parquet",
        description="Current ticks of Uniswap V3 wooo-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wooo-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/wooo_WETH_10000/merged_snaps_17613890_18074890.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for wooo-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-lpt-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_LPT_3000/merged_snaps_12943995_15820995.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RNG-LPT pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-lpt-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_LPT_3000/merged_ticks_12943995_15820995.parquet",
        description="Current ticks of Uniswap V3 RNG-LPT pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-par-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PAR_USDC_500/merged_ticks_14454303_18040303.parquet",
        description="Current ticks of Uniswap V3 PAR-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-par-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PAR_USDC_500/merged_snaps_14454303_18040303.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PAR-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-sifum-usdt-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/SifuM_USDT_10000/merged_snaps_15772808_16124808.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for SifuM-USDT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-sifum-usdt-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/SifuM_USDT_10000/merged_ticks_15772808_16124808.parquet",
        description="Current ticks of Uniswap V3 SifuM-USDT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-spot-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_SPOT_3000/merged_ticks_16142126_18080126.parquet",
        description="Current ticks of Uniswap V3 USDC-SPOT pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-spot-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_SPOT_3000/merged_snaps_16142126_18080126.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-SPOT pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-xen-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/XEN_WETH_10000/merged_snaps_15712267_18091267.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for XEN-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-xen-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/XEN_WETH_10000/merged_ticks_15712267_18091267.parquet",
        description="Current ticks of Uniswap V3 XEN-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-qanx-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/QANX_WETH_3000/merged_snaps_16688445_18088445.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for QANX-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-qanx-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/QANX_WETH_3000/merged_ticks_16688445_18088445.parquet",
        description="Current ticks of Uniswap V3 QANX-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe3r-weth-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE3R_WETH_100/merged_ticks_17936195_18042195.parquet",
        description="Current ticks of Uniswap V3 PEPE3R-WETH pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe3r-weth-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE3R_WETH_100/merged_snaps_17936195_18042195.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PEPE3R-WETH pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-hex-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/HEX_USDC_3000/merged_snaps_12376598_18088598.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for HEX-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-hex-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/HEX_USDC_3000/merged_ticks_12376598_18088598.parquet",
        description="Current ticks of Uniswap V3 HEX-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-temp-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_TEMP_10000/merged_ticks_13641209_17776209.parquet",
        description="Current ticks of Uniswap V3 USDC-TEMP pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-temp-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_TEMP_10000/merged_snaps_13641209_17776209.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-TEMP pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_WETH_3000/merged_ticks_12369739_18088739.parquet",
        description="Current ticks of Uniswap V3 UNI-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_WETH_3000/merged_snaps_12369739_18088739.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ben-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BEN_WETH_3000/merged_ticks_17197501_18088501.parquet",
        description="Current ticks of Uniswap V3 BEN-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ben-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BEN_WETH_3000/merged_snaps_17197501_18088501.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BEN-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pet-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PET_WETH_10000/merged_ticks_16373351_17837351.parquet",
        description="Current ticks of Uniswap V3 PET-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pet-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PET_WETH_10000/merged_snaps_16373351_17837351.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PET-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-link-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_LINK_3000/merged_ticks_17546463_17546463.parquet",
        description="Current ticks of Uniswap V3 RNG-LINK pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-link-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_LINK_3000/merged_snaps_17546463_17546463.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RNG-LINK pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-prime-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PRIME_WETH_3000/merged_snaps_16841205_18089205.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PRIME-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-prime-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PRIME_WETH_3000/merged_ticks_16841205_18089205.parquet",
        description="Current ticks of Uniswap V3 PRIME-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-nftx-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/NFTX_WETH_10000/merged_ticks_14762786_17880786.parquet",
        description="Current ticks of Uniswap V3 NFTX-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-nftx-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/NFTX_WETH_10000/merged_snaps_14762786_17880786.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for NFTX-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ldo-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LDO_WETH_3000/merged_snaps_12512163_18088163.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LDO-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ldo-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LDO_WETH_3000/merged_ticks_12512163_18088163.parquet",
        description="Current ticks of Uniswap V3 LDO-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-steth-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/stETH_WETH_10000/merged_ticks_14937573_18053573.parquet",
        description="Current ticks of Uniswap V3 stETH-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-steth-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/stETH_WETH_10000/merged_snaps_14937573_18053573.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for stETH-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-orc-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/ORC_WETH_3000/merged_ticks_14080888_18070888.parquet",
        description="Current ticks of Uniswap V3 ORC-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-orc-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/ORC_WETH_3000/merged_snaps_14080888_18070888.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for ORC-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dust-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DUST_WETH_3000/merged_snaps_16876882_18088882.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DUST-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dust-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DUST_WETH_3000/merged_ticks_16876882_18088882.parquet",
        description="Current ticks of Uniswap V3 DUST-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-ant-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_ANT_10000/merged_snaps_17215307_18090307.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-ANT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-ant-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_ANT_10000/merged_ticks_17215307_18090307.parquet",
        description="Current ticks of Uniswap V3 USDC-ANT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mnt-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/MNT_WETH_3000/merged_ticks_17712654_18032654.parquet",
        description="Current ticks of Uniswap V3 MNT-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mnt-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/MNT_WETH_3000/merged_snaps_17712654_18032654.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for MNT-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_WETH_10000/merged_ticks_16628649_18089649.parquet",
        description="Current ticks of Uniswap V3 BLUR-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_WETH_10000/merged_snaps_16628649_18089649.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BLUR-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-zusd-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_ZUSD_500/merged_ticks_16420225_17871225.parquet",
        description="Current ticks of Uniswap V3 USDC-ZUSD pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-zusd-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_ZUSD_500/merged_snaps_16420225_17871225.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-ZUSD pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-fpi-frax-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/FPI_FRAX_3000/merged_snaps_14484746_18057746.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for FPI-FRAX pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-fpi-frax-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/FPI_FRAX_3000/merged_ticks_14484746_18057746.parquet",
        description="Current ticks of Uniswap V3 FPI-FRAX pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-ela-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_ELA_3000/merged_snaps_12724933_15698933.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-ELA pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-ela-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_ELA_3000/merged_ticks_12724933_15698933.parquet",
        description="Current ticks of Uniswap V3 WETH-ELA pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-crv-crvusd-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/CRV_crvUSD_3000/merged_snaps_18038723_18087723.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for CRV-crvUSD pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-crv-crvusd-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/CRV_crvUSD_3000/merged_ticks_18038723_18087723.parquet",
        description="Current ticks of Uniswap V3 CRV-crvUSD pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-shib-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/SHIB_WETH_3000/merged_ticks_12376028_18091028.parquet",
        description="Current ticks of Uniswap V3 SHIB-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-shib-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/SHIB_WETH_3000/merged_snaps_12376028_18091028.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for SHIB-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdd-usdt-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDD_USDT_100/merged_snaps_14692694_15807694.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDD-USDT pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdd-usdt-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDD_USDT_100/merged_ticks_14692694_15807694.parquet",
        description="Current ticks of Uniswap V3 USDD-USDT pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDC_500/merged_snaps_12561607_18088607.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDC_500/merged_ticks_12561607_18088607.parquet",
        description="Current ticks of Uniswap V3 WBTC-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-badger-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BADGER_WETH_10000/merged_ticks_12740245_17785245.parquet",
        description="Current ticks of Uniswap V3 BADGER-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-badger-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BADGER_WETH_10000/merged_snaps_12740245_17785245.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BADGER-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_USDC_500/merged_ticks_12399631_18071631.parquet",
        description="Current ticks of Uniswap V3 LUSD-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_USDC_500/merged_snaps_12399631_18071631.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LUSD-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_USDC_3000/merged_snaps_14420259_17997259.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for wstETH-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_USDC_3000/merged_ticks_14420259_17997259.parquet",
        description="Current ticks of Uniswap V3 wstETH-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-eul-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_EUL_10000/merged_snaps_14554721_18089721.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-EUL pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-eul-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_EUL_10000/merged_ticks_14554721_18089721.parquet",
        description="Current ticks of Uniswap V3 WETH-EUL pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-brz-usdt-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BRZ_USDT_100/merged_ticks_17658371_17658371.parquet",
        description="Current ticks of Uniswap V3 BRZ-USDT pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-brz-usdt-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BRZ_USDT_100/merged_snaps_17658371_17658371.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BRZ-USDT pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-yfi-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/YFI_WETH_10000/merged_snaps_12379392_18055392.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for YFI-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-yfi-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/YFI_WETH_10000/merged_ticks_12379392_18055392.parquet",
        description="Current ticks of Uniswap V3 YFI-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_WETH_10000/merged_ticks_12376022_17940022.parquet",
        description="Current ticks of Uniswap V3 DAI-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_WETH_10000/merged_snaps_12376022_17940022.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arb-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/ARB_WETH_10000/merged_ticks_16889646_18088646.parquet",
        description="Current ticks of Uniswap V3 ARB-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arb-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/ARB_WETH_10000/merged_snaps_16889646_18088646.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for ARB-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_WETH_3000/merged_ticks_12890749_17939749.parquet",
        description="Current ticks of Uniswap V3 RNG-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rng-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RNG_WETH_3000/merged_snaps_12890749_17939749.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RNG-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frxeth-frax-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/frxETH_FRAX_10000/merged_snaps_16445031_18058031.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for frxETH-FRAX pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frxeth-frax-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/frxETH_FRAX_10000/merged_ticks_16445031_18058031.parquet",
        description="Current ticks of Uniswap V3 frxETH-FRAX pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-crv-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_CRV_10000/merged_ticks_12376543_18075543.parquet",
        description="Current ticks of Uniswap V3 WETH-CRV pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-crv-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_CRV_10000/merged_snaps_12376543_18075543.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-CRV pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cream-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/CREAM_WETH_10000/merged_snaps_12616124_17961124.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for CREAM-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cream-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/CREAM_WETH_10000/merged_ticks_12616124_17961124.parquet",
        description="Current ticks of Uniswap V3 CREAM-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-link-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_LINK_3000/merged_snaps_12378853_18068853.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-LINK pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-link-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_LINK_3000/merged_ticks_12378853_18068853.parquet",
        description="Current ticks of Uniswap V3 UNI-LINK pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE_WETH_10000/merged_ticks_17988663_18090663.parquet",
        description="Current ticks of Uniswap V3 PEPE-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE_WETH_10000/merged_snaps_17988663_18090663.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PEPE-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mim-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/MIM_USDC_500/merged_snaps_12637897_15584897.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for MIM-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mim-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/MIM_USDC_500/merged_ticks_12637897_17980897.parquet",
        description="Current ticks of Uniswap V3 MIM-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mim-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/MIM_USDC_500/merged_ticks_12637897_15584897.parquet",
        description="Current ticks of Uniswap V3 MIM-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-mim-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/MIM_USDC_500/merged_snaps_12637897_17980897.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for MIM-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_WETH_3000/merged_snaps_12369821_18977821.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-wsteth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_wstETH_500/merged_snaps_17925098_18038098.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-wstETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-wsteth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_wstETH_500/merged_ticks_17925098_18038098.parquet",
        description="Current ticks of Uniswap V3 WBTC-wstETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-tbtc-wbtc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/tBTC_WBTC_500/merged_ticks_16541362_18083362.parquet",
        description="Current ticks of Uniswap V3 tBTC-WBTC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-tbtc-wbtc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/tBTC_WBTC_500/merged_snaps_16541362_18083362.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for tBTC-WBTC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frxeth-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/frxETH_WETH_500/merged_ticks_16642907_18084907.parquet",
        description="Current ticks of Uniswap V3 frxETH-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frxeth-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/frxETH_WETH_500/merged_snaps_16642907_18084907.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for frxETH-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-weth-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_WETH_100/merged_snaps_15384250_18090250.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for wstETH-WETH pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-weth-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_WETH_100/merged_ticks_15384250_18090250.parquet",
        description="Current ticks of Uniswap V3 wstETH-WETH pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-usdc-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_USDC_10000/merged_ticks_18009173_18080173.parquet",
        description="Current ticks of Uniswap V3 LUSD-USDC pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-usdc-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_USDC_10000/merged_snaps_18009173_18080173.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LUSD-USDC pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdd-mim-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDD_MIM_100/merged_ticks_14731082_14731082.parquet",
        description="Current ticks of Uniswap V3 USDD-MIM pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdd-mim-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDD_MIM_100/merged_snaps_14731082_14731082.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDD-MIM pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gohm-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/gOHM_USDC_3000/merged_snaps_14402095_18082095.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for gOHM-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gohm-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/gOHM_USDC_3000/merged_ticks_14402095_18082095.parquet",
        description="Current ticks of Uniswap V3 gOHM-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_WETH_500/merged_ticks_12376093_18070093.parquet",
        description="Current ticks of Uniswap V3 wstETH-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wsteth-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/wstETH_WETH_500/merged_snaps_12376093_18070093.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for wstETH-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-psyop-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PSYOP_WETH_3000/merged_snaps_17286843_17796843.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PSYOP-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-psyop-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PSYOP_WETH_3000/merged_ticks_17286843_17796843.parquet",
        description="Current ticks of Uniswap V3 PSYOP-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-1inch-usdc-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/1INCH_USDC_10000/merged_snaps_12376706_18040706.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for 1INCH-USDC pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-1inch-usdc-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/1INCH_USDC_10000/merged_ticks_12376706_18040706.parquet",
        description="Current ticks of Uniswap V3 1INCH-USDC pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dydx-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DYDX_WETH_10000/merged_ticks_13182985_18037985.parquet",
        description="Current ticks of Uniswap V3 DYDX-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dydx-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DYDX_WETH_10000/merged_snaps_13182985_18037985.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DYDX-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-olas-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/OLAS_WETH_10000/merged_ticks_17740893_18089893.parquet",
        description="Current ticks of Uniswap V3 OLAS-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-olas-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/OLAS_WETH_10000/merged_snaps_17740893_18089893.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for OLAS-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-crvusd-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_crvUSD_500/merged_ticks_17355131_18088131.parquet",
        description="Current ticks of Uniswap V3 USDC-crvUSD pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-crvusd-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_crvUSD_500/merged_snaps_17355131_18088131.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-crvUSD pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-nexo-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/NEXO_WETH_3000/merged_snaps_12376925_18072925.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for NEXO-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-nexo-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/NEXO_WETH_3000/merged_ticks_12376925_18072925.parquet",
        description="Current ticks of Uniswap V3 NEXO-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-1inch-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/1INCH_WETH_10000/merged_ticks_12381209_18081209.parquet",
        description="Current ticks of Uniswap V3 1INCH-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-1inch-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/1INCH_WETH_10000/merged_snaps_12381209_18081209.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for 1INCH-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdc-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDC_10000/merged_ticks_12601908_17961908.parquet",
        description="Current ticks of Uniswap V3 WBTC-USDC pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdc-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDC_10000/merged_snaps_12601908_17961908.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-USDC pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-frax-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_FRAX_500/merged_ticks_12523889_18068889.parquet",
        description="Current ticks of Uniswap V3 DAI-FRAX pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-frax-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_FRAX_500/merged_snaps_12523889_18068889.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-FRAX pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-trac-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/TRAC_WETH_3000/merged_ticks_12383469_18059469.parquet",
        description="Current ticks of Uniswap V3 TRAC-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-trac-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/TRAC_WETH_3000/merged_snaps_12383469_18059469.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for TRAC-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_WETH_10000/merged_ticks_12376536_17944536.parquet",
        description="Current ticks of Uniswap V3 WBTC-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_WETH_10000/merged_snaps_12376536_17944536.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-lqty-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_LQTY_10000/merged_ticks_15885859_16489859.parquet",
        description="Current ticks of Uniswap V3 WBTC-LQTY pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-lqty-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_LQTY_10000/merged_snaps_15885859_16489859.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-LQTY pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ldo-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LDO_WETH_10000/merged_snaps_12506934_18050934.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LDO-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ldo-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LDO_WETH_10000/merged_ticks_12506934_18050934.parquet",
        description="Current ticks of Uniswap V3 LDO-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rai-dai-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RAI_DAI_500/merged_ticks_12375267_17954267.parquet",
        description="Current ticks of Uniswap V3 RAI-DAI pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rai-dai-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RAI_DAI_500/merged_snaps_12375267_17954267.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RAI-DAI pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sol-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_SOL_3000/merged_snaps_13585746_18089746.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-SOL pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sol-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_SOL_3000/merged_ticks_13585746_18089746.parquet",
        description="Current ticks of Uniswap V3 WETH-SOL pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_USDC_3000/merged_snaps_12414460_17861460.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for FRAX-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_USDC_3000/merged_ticks_12414460_17861460.parquet",
        description="Current ticks of Uniswap V3 FRAX-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-glo-usdt-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/GLO_USDT_10000/merged_ticks_16465020_16542020.parquet",
        description="Current ticks of Uniswap V3 GLO-USDT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-glo-usdt-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/GLO_USDT_10000/merged_snaps_16465020_16542020.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for GLO-USDT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE_WETH_3000/merged_snaps_17083569_18089569.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for PEPE-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-pepe-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/PEPE_WETH_3000/merged_ticks_17083569_18089569.parquet",
        description="Current ticks of Uniswap V3 PEPE-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ageur-usdc-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/agEUR_USDC_100/merged_snaps_14615707_18050707.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for agEUR-USDC pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ageur-usdc-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/agEUR_USDC_100/merged_ticks_14615707_18050707.parquet",
        description="Current ticks of Uniswap V3 agEUR-USDC pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-usdt-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_USDT_3000/merged_ticks_12378852_18089852.parquet",
        description="Current ticks of Uniswap V3 UNI-USDT pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-usdt-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_USDT_3000/merged_snaps_12378852_18089852.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-USDT pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_WETH_10000/merged_ticks_12369811_18071811.parquet",
        description="Current ticks of Uniswap V3 USDC-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_WETH_10000/merged_snaps_12369811_18071811.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ocean-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/OCEAN_WETH_3000/merged_snaps_12385812_18084812.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for OCEAN-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ocean-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/OCEAN_WETH_3000/merged_ticks_12385812_18084812.parquet",
        description="Current ticks of Uniswap V3 OCEAN-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_WETH_500/merged_snaps_12375738_18089738.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_WETH_500/merged_ticks_12375738_18089738.parquet",
        description="Current ticks of Uniswap V3 DAI-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-inj-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_INJ_3000/merged_snaps_12583193_18088193.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-INJ pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-inj-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_INJ_3000/merged_ticks_12583193_18088193.parquet",
        description="Current ticks of Uniswap V3 WETH-INJ pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-index-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/INDEX_WETH_10000/merged_snaps_12515929_18084929.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for INDEX-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-index-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/INDEX_WETH_10000/merged_ticks_12515929_18084929.parquet",
        description="Current ticks of Uniswap V3 INDEX-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_500/merged_snaps_12369863_18068863.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-USDT pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_500/merged_ticks_12369863_18068863.parquet",
        description="Current ticks of Uniswap V3 USDC-USDT pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sweth-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_swETH_100/merged_snaps_17925194_18089194.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-swETH pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sweth-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_swETH_100/merged_ticks_17925194_18089194.parquet",
        description="Current ticks of Uniswap V3 WETH-swETH pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-ens-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_ENS_3000/merged_snaps_13578816_18062816.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-ENS pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-ens-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_ENS_3000/merged_ticks_13578816_18062816.parquet",
        description="Current ticks of Uniswap V3 WETH-ENS pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lqty-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LQTY_WETH_3000/merged_ticks_12369922_18074922.parquet",
        description="Current ticks of Uniswap V3 LQTY-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lqty-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LQTY_WETH_3000/merged_snaps_12369922_18074922.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LQTY-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-link-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LINK_WETH_3000/merged_snaps_12375680_18088680.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LINK-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-link-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LINK_WETH_3000/merged_ticks_12375680_18088680.parquet",
        description="Current ticks of Uniswap V3 LINK-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_100/merged_snaps_13609065_18086065.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-USDT pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_100/merged_ticks_13609065_18086065.parquet",
        description="Current ticks of Uniswap V3 USDC-USDT pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sweth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_swETH_500/merged_snaps_17150305_18089305.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-swETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-sweth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_swETH_500/merged_ticks_17150305_18089305.parquet",
        description="Current ticks of Uniswap V3 WETH-swETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-usdt-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_USDT_10000/merged_ticks_12376237_18066237.parquet",
        description="Current ticks of Uniswap V3 WETH-USDT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-usdt-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_USDT_10000/merged_snaps_12376237_18066237.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-USDT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-bob-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BOB_WETH_500/merged_ticks_15666096_18065096.parquet",
        description="Current ticks of Uniswap V3 BOB-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-bob-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BOB_WETH_500/merged_snaps_15666096_18065096.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BOB-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-alusd-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_alUSD_500/merged_ticks_13025692_17949692.parquet",
        description="Current ticks of Uniswap V3 FRAX-alUSD pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-alusd-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_alUSD_500/merged_snaps_13025692_17949692.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for FRAX-alUSD pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rare-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RARE_WETH_3000/merged_snaps_13043788_18023788.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RARE-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rare-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RARE_WETH_3000/merged_ticks_13043788_18023788.parquet",
        description="Current ticks of Uniswap V3 RARE-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdt-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDT_3000/merged_ticks_12376091_18089091.parquet",
        description="Current ticks of Uniswap V3 WBTC-USDT pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-usdt-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_USDT_3000/merged_snaps_12376091_18089091.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-USDT pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-usdt-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_USDT_500/merged_ticks_12376751_18089751.parquet",
        description="Current ticks of Uniswap V3 WETH-USDT pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-usdt-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_USDT_500/merged_snaps_12376751_18089751.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-USDT pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_WETH_500/merged_snaps_12376729_18089729.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_WETH_500/merged_ticks_12376729_18089729.parquet",
        description="Current ticks of Uniswap V3 USDC-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-chz-usdt-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/CHZ_USDT_3000/merged_ticks_12605573_18042573.parquet",
        description="Current ticks of Uniswap V3 CHZ-USDT pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-chz-usdt-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/CHZ_USDT_3000/merged_snaps_12605573_18042573.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for CHZ-USDT pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-xdefi-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/XDEFI_WETH_10000/merged_snaps_14823170_18083170.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for XDEFI-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-xdefi-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/XDEFI_WETH_10000/merged_ticks_14823170_18083170.parquet",
        description="Current ticks of Uniswap V3 XDEFI-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rbn-weth-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RBN_WETH_10000/merged_ticks_13366343_17755343.parquet",
        description="Current ticks of Uniswap V3 RBN-WETH pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rbn-weth-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RBN_WETH_10000/merged_snaps_13366343_17755343.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RBN-WETH pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-matic-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/MATIC_WETH_3000/merged_snaps_12376420_18088420.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for MATIC-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-matic-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/MATIC_WETH_3000/merged_ticks_12376420_18088420.parquet",
        description="Current ticks of Uniswap V3 MATIC-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-bob-usdt-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BOB_USDT_100/merged_ticks_15845788_18064788.parquet",
        description="Current ticks of Uniswap V3 BOB-USDT pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-bob-usdt-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BOB_USDT_100/merged_snaps_15845788_18064788.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BOB-USDT pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDC_500/merged_snaps_12369760_18081760.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDC_500/merged_ticks_12369760_18081760.parquet",
        description="Current ticks of Uniswap V3 DAI-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdt-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDT_500/merged_snaps_12370078_18071078.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-USDT pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdt-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDT_500/merged_ticks_12370078_18071078.parquet",
        description="Current ticks of Uniswap V3 DAI-USDT pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ape-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/APE_WETH_3000/merged_ticks_14403763_18089763.parquet",
        description="Current ticks of Uniswap V3 APE-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ape-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/APE_WETH_3000/merged_snaps_14403763_18089763.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for APE-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-fpis-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_FPIS_10000/merged_snaps_14546561_18058561.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for FRAX-FPIS pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-frax-fpis-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/FRAX_FPIS_10000/merged_ticks_14546561_18058561.parquet",
        description="Current ticks of Uniswap V3 FRAX-FPIS pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rbn-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/RBN_USDC_3000/merged_snaps_13897558_18062558.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for RBN-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-rbn-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/RBN_USDC_3000/merged_ticks_13897558_18062558.parquet",
        description="Current ticks of Uniswap V3 RBN-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-rng-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_RNG_3000/merged_snaps_17496128_17496128.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WBTC-RNG pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-wbtc-rng-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WBTC_RNG_3000/merged_ticks_17496128_17496128.parquet",
        description="Current ticks of Uniswap V3 WBTC-RNG pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_10000/merged_ticks_12375837_18063837.parquet",
        description="Current ticks of Uniswap V3 USDC-USDT pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-usdt-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_USDT_10000/merged_snaps_12375837_18063837.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-USDT pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-babywojak-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BABYWOJAK_WETH_3000/merged_ticks_18049440_18076440.parquet",
        description="Current ticks of Uniswap V3 BABYWOJAK-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-babywojak-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BABYWOJAK_WETH_3000/merged_snaps_18049440_18076440.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BABYWOJAK-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ageur-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/agEUR_WETH_500/merged_snaps_14526075_18026075.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for agEUR-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-ageur-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/agEUR_WETH_500/merged_ticks_14526075_18026075.parquet",
        description="Current ticks of Uniswap V3 agEUR-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_WETH_3000/merged_snaps_16629169_18090169.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for BLUR-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-blur-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/BLUR_WETH_3000/merged_ticks_16629169_18090169.parquet",
        description="Current ticks of Uniswap V3 BLUR-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cvx-crv-10000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/CVX_CRV_10000/merged_ticks_12988928_18062928.parquet",
        description="Current ticks of Uniswap V3 CVX-CRV pool with 1.0 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cvx-crv-10000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/CVX_CRV_10000/merged_snaps_12988928_18062928.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for CVX-CRV pool with 1.0 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdc-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDC_100/merged_ticks_13605124_18088124.parquet",
        description="Current ticks of Uniswap V3 DAI-USDC pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdc-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDC_100/merged_snaps_13605124_18088124.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-USDC pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdt-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDT_100/merged_ticks_15142784_18084784.parquet",
        description="Current ticks of Uniswap V3 DAI-USDT pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-dai-usdt-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/DAI_USDT_100/merged_snaps_15142784_18084784.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for DAI-USDT pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gohm-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/gOHM_WETH_3000/merged_ticks_15432039_18077039.parquet",
        description="Current ticks of Uniswap V3 gOHM-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gohm-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/gOHM_WETH_3000/merged_snaps_15432039_18077039.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for gOHM-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-vega-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_VEGA_3000/merged_ticks_13149422_18082422.parquet",
        description="Current ticks of Uniswap V3 WETH-VEGA pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-weth-vega-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/WETH_VEGA_3000/merged_snaps_13149422_18082422.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for WETH-VEGA pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gbtc-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/GBTC_WETH_3000/merged_ticks_18026558_18053558.parquet",
        description="Current ticks of Uniswap V3 GBTC-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gbtc-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/GBTC_WETH_3000/merged_snaps_18026558_18053558.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for GBTC-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-comp-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/COMP_WETH_3000/merged_ticks_12370351_18071351.parquet",
        description="Current ticks of Uniswap V3 COMP-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-comp-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/COMP_WETH_3000/merged_snaps_12370351_18071351.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for COMP-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-usdc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_USDC_3000/merged_snaps_12378453_18073453.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-USDC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-usdc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_USDC_3000/merged_ticks_12378453_18073453.parquet",
        description="Current ticks of Uniswap V3 UNI-USDC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-euroe-usdc-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/EUROe_USDC_500/merged_ticks_16535389_18062389.parquet",
        description="Current ticks of Uniswap V3 EUROe-USDC pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-euroe-usdc-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/EUROe_USDC_500/merged_snaps_16535389_18062389.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for EUROe-USDC pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-reth-weth-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/rETH_WETH_500/merged_ticks_14155364_18089364.parquet",
        description="Current ticks of Uniswap V3 rETH-WETH pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-reth-weth-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/rETH_WETH_500/merged_snaps_14155364_18089364.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for rETH-WETH pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gamma-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/GAMMA_WETH_3000/merged_ticks_13870588_18024588.parquet",
        description="Current ticks of Uniswap V3 GAMMA-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-gamma-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/GAMMA_WETH_3000/merged_snaps_13870588_18024588.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for GAMMA-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-aave-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/AAVE_WETH_3000/merged_snaps_12375644_18088644.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for AAVE-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-aave-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/AAVE_WETH_3000/merged_ticks_12375644_18088644.parquet",
        description="Current ticks of Uniswap V3 AAVE-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arb-weth-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/ARB_WETH_3000/merged_snaps_16889197_18076197.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for ARB-WETH pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-arb-weth-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/ARB_WETH_3000/merged_ticks_16889197_18076197.parquet",
        description="Current ticks of Uniswap V3 ARB-WETH pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-blusd-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_bLUSD_500/merged_snaps_17307880_18081880.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for LUSD-bLUSD pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-lusd-blusd-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/LUSD_bLUSD_500/merged_ticks_17307880_18081880.parquet",
        description="Current ticks of Uniswap V3 LUSD-bLUSD pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cdai-dai-500-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/cDAI_DAI_500/merged_ticks_12543946_17475946.parquet",
        description="Current ticks of Uniswap V3 cDAI-DAI pool with 0.05 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-cdai-dai-500-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/cDAI_DAI_500/merged_snaps_12543946_17475946.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for cDAI-DAI pool with 0.05 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-bob-100-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_BOB_100/merged_snaps_15832657_16136657.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for USDC-BOB pool with 0.01 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-usdc-bob-100-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/USDC_BOB_100/merged_ticks_15832657_16136657.parquet",
        description="Current ticks of Uniswap V3 USDC-BOB pool with 0.01 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-wbtc-3000-current-ticks",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_WBTC_3000/merged_ticks_12386562_16477562.parquet",
        description="Current ticks of Uniswap V3 UNI-WBTC pool with 0.3 % fee in 1000 blocks intervals",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
    Dataset(
        name="uniswapv3-ethereum-uni-wbtc-3000-liquidity-snapshots",
        path="gs://datasets-giza/UniswapV3/ethereum/UNI_WBTC_3000/merged_snaps_12386562_16477562.parquet",
        description="Snapshots of Uniswap V3 liquidity distribution in 1000 blocks intervals for UNI-WBTC pool with 0.3 % fee",
        tags=["Uniswap-v3", "Liquidity", "Ethereum", "DeFi", "DEX"],
        documentation="https://datasets.gizatech.xyz/hub-pending/uniswap-v3-liquidity-distribution",
    ),
]
